# -*- coding: utf-8 -*-

from django.db import models
from django.utils.translation import ugettext_lazy as _
from shortuuidfield import ShortUUIDField

from tamron.basemodels import CreateUpdateMixin, SexChoicesMixin


class FranchiserInfo(CreateUpdateMixin):
    franchiser_id = ShortUUIDField(_(u'franchiser_id'), max_length=255, help_text=u'经销商唯一标识', db_index=True, unique=True)
    franchiser_name = models.CharField(_(u'franchiser_name'), max_length=255, blank=True, null=True, help_text=u'经销商名称')
    franchiser_addr = models.CharField(_(u'franchiser_addr'), max_length=255, blank=True, null=True, help_text=u'经销商地址')
    franchiser_phone = models.CharField(_(u'franchiser_phone'), max_length=255, blank=True, null=True, help_text=u'经销商联系电话')
    franchiser_boss_name = models.CharField(_(u'franchiser_boss_name'), max_length=255, blank=True, null=True, help_text=u'经销商老板名称')
    franchiser_boss_phone = models.CharField(_(u'franchiser_boss_phone'), max_length=255, blank=True, null=True, help_text=u'经销商老板联系电话')

    class Meta:
        verbose_name = _(u'经销商信息表')
        verbose_name_plural = _(u'经销商信息表')

    def __unicode__(self):
        return unicode(self.pk)

    @property
    def data(self):
        return {
            'franchiser_id': self.franchiser_id,
            'franchiser_name': self.franchiser_name,
        }


class SaleclerkInfo(CreateUpdateMixin, SexChoicesMixin):
    REFUSED = -1
    UNVERIFIED = 0
    ACTIVATED = 1
    DISABLED = 2
    DELETED = 3
    ASSIGN = 10

    USER_STATUS = (
        (REFUSED, u'已拒绝'),
        (UNVERIFIED, u'未验证'),
        (ACTIVATED, u'已激活'),
        (DISABLED, u'已禁用'),
        (DELETED, u'已删除'),
        (ASSIGN, u'已分配'),
    )

    franchiser_id = models.CharField(_(u'franchiser_id'), max_length=255, blank=True, null=True, help_text=u'经销商唯一标识', db_index=True)
    franchiser_name = models.CharField(_(u'franchiser_name'), max_length=255, blank=True, null=True, help_text=u'经销商名称')
    clerk_id = ShortUUIDField(_(u'clerk_id'), max_length=255, help_text=u'店员唯一标识', db_index=True, unique=True)
    clerk_name = models.CharField(_(u'clerk_name'), max_length=255, blank=True, null=True, help_text=u'店员名称')
    clerk_sex = models.IntegerField(_(u'clerk_sex'), choices=SexChoicesMixin.SEX_TYPE, default=SexChoicesMixin.MALE, help_text=u'店员性别', db_index=True)
    clerk_phone = models.CharField(_(u'clerk_phone'), max_length=255, blank=True, null=True, help_text=u'店员联系电话')

    openid = models.CharField(_(u'openid'), max_length=255, blank=True, null=True, help_text=u'微信 OpenID', db_index=True, unique=True)
    unionid = models.CharField(_(u'unionid'), max_length=255, blank=True, null=True, help_text=u'微信 UnionID', db_index=True, unique=True)

    integral = models.IntegerField(_(u'integral'), default=0, help_text=u'积分')

    user_status = models.IntegerField(_(u'user_status'), choices=USER_STATUS, default=UNVERIFIED, help_text=u'用户状态', db_index=True)
    refused_reason = models.TextField(_(u'refused_reason'), blank=True, null=True, help_text=u'审核拒绝原因')

    class Meta:
        verbose_name = _(u'saleclerkinfo')
        verbose_name_plural = _(u'saleclerkinfo')

    def __unicode__(self):
        return unicode(self.pk)

    @property
    def data(self):
        return {
            'franchiser_id': self.franchiser_id,
            'franchiser_name': self.franchiser_name,
            'clerk_id': self.clerk_id,
            'clerk_name': self.clerk_name,
            'clerk_sex': self.clerk_sex,
            'clerk_phone': self.clerk_phone,
            'integral': self.integral,
            'status': self.user_status,
            'refused_reason': self.refused_reason,
        }
